@@ -5,10 +5,11 @@ import numpy as np
 from .geometry import (
     support_function_capsule, support_function_cylinder,
     convert_box_to_vertices, support_function_ellipsoid,
-    support_function_sphere, support_function_cone, support_function_disk)
+    support_function_sphere, support_function_cone, support_function_disk,
+    support_function_ellipse)
 from .containment import (
     axis_aligned_bounding_box, sphere_aabb, box_aabb, cylinder_aabb,
-    capsule_aabb, ellipsoid_aabb, cone_aabb, disk_aabb)
+    capsule_aabb, ellipsoid_aabb, cone_aabb, disk_aabb, ellipse_aabb)
 from .mesh import MeshHillClimbingSupportFunction
 from .utils import plane_basis_from_normal, norm_vector
 from aabbtree import AABB
@@ -128,8 +129,7 @@ class ConvexHullVertices(ConvexCollider):
         raise NotImplementedError("update_pose is not implemented!")
 
     def aabb(self):
-        mins, maxs = axis_aligned_bounding_box(self.vertices)
-        return AABB(np.array([mins, maxs]).T)
+        return AABB(np.array(axis_aligned_bounding_box(self.vertices)).T)
 
 
 class Box(ConvexHullVertices):
@@ -166,8 +166,7 @@ class Box(ConvexHullVertices):
             self.artist_.set_data(pose)
 
     def aabb(self):
-        mins, maxs = box_aabb(self.box2origin, self.size)
-        return AABB(np.array([mins, maxs]).T)
+        return AABB(np.array(box_aabb(self.box2origin, self.size)).T)
 
 
 class MeshGraph(ConvexCollider):
@@ -218,10 +217,9 @@ class MeshGraph(ConvexCollider):
             self.artist_.set_data(mesh2origin)
 
     def aabb(self):
-        mins, maxs = axis_aligned_bounding_box(
+        return AABB(np.array(axis_aligned_bounding_box(
             self.mesh2origin[np.newaxis, :3, 3] + np.dot(
-                self.vertices, self.mesh2origin[:3, :3].T))
-        return AABB(np.array([mins, maxs]).T)
+                self.vertices, self.mesh2origin[:3, :3].T))).T)
 
 
 class Sphere(ConvexCollider):
@@ -265,8 +263,7 @@ class Sphere(ConvexCollider):
             self.artist_.set_data(pose)
 
     def aabb(self):
-        mins, maxs = sphere_aabb(self.c, self.radius)
-        return AABB(np.array([mins, maxs]).T)
+        return AABB(np.array(sphere_aabb(self.c, self.radius)).T)
 
 
 class Capsule(ConvexCollider):
@@ -315,9 +312,8 @@ class Capsule(ConvexCollider):
             self.artist_.set_data(pose)
 
     def aabb(self):
-        mins, maxs = capsule_aabb(
-            self.capsule2origin, self.radius, self.height)
-        return AABB(np.array([mins, maxs]).T)
+        return AABB(np.array(capsule_aabb(
+            self.capsule2origin, self.radius, self.height)).T)
 
 
 class Ellipsoid(ConvexCollider):
@@ -361,8 +357,8 @@ class Ellipsoid(ConvexCollider):
             self.artist_.set_data(pose)
 
     def aabb(self):
-        mins, maxs = ellipsoid_aabb(self.ellipsoid2origin, self.radii)
-        return AABB(np.array([mins, maxs]).T)
+        return AABB(
+            np.array(ellipsoid_aabb(self.ellipsoid2origin, self.radii)).T)
 
 
 class Cylinder(ConvexCollider):
@@ -411,9 +407,8 @@ class Cylinder(ConvexCollider):
             self.artist_.set_data(pose)
 
     def aabb(self):
-        mins, maxs = cylinder_aabb(
-            self.cylinder2origin, self.radius, self.length)
-        return AABB(np.array([mins, maxs]).T)
+        return AABB(np.array(cylinder_aabb(
+            self.cylinder2origin, self.radius, self.length)).T)
 
 
 class Disk(ConvexCollider):
@@ -467,8 +462,54 @@ class Disk(ConvexCollider):
             self.artist_.set_data(pose)
 
     def aabb(self):
-        mins, maxs = disk_aabb(self.c, self.radius, self.normal)
-        return AABB(np.array([mins, maxs]).T)
+        return AABB(np.array(disk_aabb(self.c, self.radius, self.normal)).T)
+
+
+class Ellipse(ConvexCollider):
+    """Ellipse collider.
+
+    Parameters
+    ----------
+    center : array, shape (3,)
+        Center of ellipse.
+
+    axes : array, shape (2, 3)
+        Axes of ellipse.
+
+    radii : array, shape (2,)
+        Radii of ellipse.
+
+    artist : pytransform3d.visualizer.Artist, optional (default: None)
+        Corresponding artist for visualizer.
+    """
+    def __init__(self, center, axes, radii, artist=None):
+        super(Ellipse, self).__init__(artist)
+        self.c = center
+        self.axes = axes
+        self.radii = radii
+
+    def make_artist(self, c=None):
+        from .visualization import Ellipse
+        self.artist_ = Ellipse(self.c, self.axes, self.radii, c=c)
+
+    def center(self):
+        return self.c
+
+    def first_vertex(self):
+        return self.c + self.axes[0] * self.radii[0]
+
+    def support_function(self, search_direction):
+        return support_function_ellipse(
+            search_direction, self.c, self.axes, self.radii)
+
+    def update_pose(self, pose):
+        self.c = pose[:3, 3]
+        self.axes = pose[:3, :2].T
+        if self.artist_ is not None:
+            self.artist_.set_data(pose)
+
+    def aabb(self):
+        return AABB(np.array(ellipse_aabb(self.c, self.axes, self.radii)).T)
 
 
 class Cone(ConvexCollider):
@@ -517,9 +558,8 @@ class Cone(ConvexCollider):
             self.artist_.set_data(pose)
 
     def aabb(self):
-        mins, maxs = cone_aabb(
-            self.cone2origin, self.radius, self.height)
-        return AABB(np.array([mins, maxs]).T)
+        return AABB(np.array(cone_aabb(
+            self.cone2origin, self.radius, self.height)).T)
 
 
 class Margin(ConvexCollider):
@@ -560,3 +600,16 @@ class Margin(ConvexCollider):
         mins = aabb.limits[:, 0] - self.margin
         maxs = aabb.limits[:, 1] + self.margin
         return AABB(np.array([mins, maxs]).T)
+
+
+COLLIDERS = {
+    "sphere": Sphere,
+    "ellipsoid": Ellipsoid,
+    "capsule": Capsule,
+    "disk": Disk,
+    "ellipse": Ellipse,
+    "cone": Cone,
+    "cylinder": Cylinder,
+    "box": Box,
+    "mesh": MeshGraph,
+}
