@@ -3,7 +3,10 @@ import numba
 import numpy as np
 from scipy.spatial import ConvexHull
 
-from .utils import HALF_PI, angles_between_vectors
+from .utils import EPSILON, HALF_PI, angles_between_vectors
+
+
+PROJECTION_LENGTH_EPSILON = 10.0 * EPSILON
 
 
 class MeshHillClimbingSupportFunction:
@@ -119,7 +122,7 @@ def hill_climb_mesh_extreme(
             vertex_diff = np.ascontiguousarray(
                 vertices[connected_idx] - vertices[best_idx])
             projected_length = search_direction.dot(vertex_diff)
-            if projected_length > 0.0:
+            if projected_length > PROJECTION_LENGTH_EPSILON:
                 best_idx = connected_idx
 
     converged = False
@@ -129,7 +132,7 @@ def hill_climb_mesh_extreme(
             vertex_diff = np.ascontiguousarray(
                 vertices[connected_idx] - vertices[best_idx])
             projected_length = search_direction.dot(vertex_diff)
-            if projected_length > 0.0:
+            if projected_length > PROJECTION_LENGTH_EPSILON:
                 best_idx = connected_idx
                 converged = False
 
